@@ -12,16 +12,18 @@ else:
 def _handle_route(self:Server, reqpath:str, request_headers):
     path = tuple(int(ind) if ind.isdigit() else ind for ind in reqpath.split("?")[0].split("/"))
     route_key = Route("")
-    failure = True
+    fail = True
     for key in self.routes.keys():
         if key.parameters == path:
             #this is the correct route
             route_key = key
-            failure = False
+            fail = False
             break
-    if failure:
+    
+    if fail:
         return self.error_404(reqpath)
 
+
     route_parameters = {}
     for pn, param in enumerate(route_key.parameters):
         if type(param) == RouteParameter:
