@@ -16,7 +16,7 @@ from .types import ContentType, ext_content_type
 from .util import TermCol, utf8len
 from . import response as res
 
-VERSION = "0.4.14"
+VERSION = "0.4.16"
 
 class Server:
 
@@ -104,12 +104,13 @@ class Server:
         
         # Get the client request
         request = client_connection.recv(1024).decode()
+        # Parse HTTP headers
+        headers = request.split('\n')
+        main_req_params = headers[0].split()
+        reqpath = main_req_params[1]
+        reqpath = reqpath[1:]
         try:
-            # Parse HTTP headers
-            headers = request.split('\n')
-            main_req_params = headers[0].split()
-            reqpath = main_req_params[1]
-            reqpath = reqpath[1:]
+            
             request_headers = self.parse_headers(headers[1:])
             
             request_print = request if self.verbose else headers[0]
@@ -147,7 +148,7 @@ class Server:
             errfile = open(os.path.join(os.path.dirname(__file__), '404.html'))
         ErrContent = errfile.read()
         errfile.close()
-        response = f'HTTP/1.1 404 NOT FOUND\n\n{ErrContent}'.encode()
+        return f'HTTP/1.1 404 NOT FOUND\n\n{ErrContent}'.encode()
     def exit(self):
         # Close socket
         self.server_socket.close()
\ No newline at end of file
